[ assignment on the data part of the dlf
Usage
# S4 method for class 'Dlf'
x[i, j] <- value
Arguments
- x
The dlf object
- i
Name or index of row OR if j is missing, name or index of column
- j
Name or index of column
- value
New value to assign
Value
An updated Dlf object with the selected rows, columns, or cells
replaced in the data slot.