Skip to contents

Write a dlf object to a file

Usage

write_dlf(dlf, path, sep = "\t", include_dlf_header = FALSE)

Arguments

dlf

Dlf object to write

path

Output path to write to

sep

Separator to use in csv file

include_dlf_header

If TRUE write the Dlf header to the beginning of the csv file

Value

Invisibly returns NULL. Called for its side effect of writing the Dlf contents to path.